@@ -1,12 +1,12 @@
 package Parse::BBCode::XHTML;
-$Parse::BBCode::XHTML::VERSION = '0.15_002'; # TRIAL
-
-$Parse::BBCode::XHTML::VERSION = '0.15002';use strict;
+use strict;
 use warnings;
+use Data::Dumper;
 use Carp qw(croak carp);
 use URI::Escape;
 use base qw/ Parse::BBCode /;
 
+our $VERSION = '0.01';
 my $email_valid = 0;
 eval {
     require
@@ -21,7 +21,7 @@ my %default_tags = (
         $text =~ s{\r?\n|\r}{<br />\n}g;
         $text;
     },
-    'img'   => '<img src="%{link}A" alt="[%{html}s]" title="%{html}s" />',
+    'img'   => '<img src="%{html}A" alt="[%{html}s]" title="%{html}s" />',
 );
 my %optional_tags = (
     Parse::BBCode::HTML->optional(),
